==> estateplat-common-1.2.3-20180119.075804-18-sources.jar: cn/gtmap/estateplat/model/stockHouse/contract/LsFcjyClfJjhtFwgk.java <==
package cn.gtmap.estateplat.model.stockHouse.contract;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
 * @version 1.0, 2018/1/16
 * @description 经纪合同房屋概况
 */
@Table(name = "ls_fcjy_clf_jjht_fwgk")
public class LsFcjyClfJjhtFwgk implements InsertVo{
    @Id
    private String id;//id
    private String jjhtid;//经纪合同id
    private String hbh;//户编号
    private String fwzl;//房屋坐落
    private String cqzh;//产权证号
    private String fwxz;//房屋性质
    private String jcnf;//建成年份
    private Double jzmj;//建筑面积
    private String xzql;//限制权利
    private Date xzqljcqx;//限制权利解除期限
    private Date jfsj;//交付时间
    private String jfzk;//交付状况
    private String qtsm;//其他说明

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getJjhtid() {
        return jjhtid;
    }

    public void setJjhtid(String jjhtid) {
        this.jjhtid = jjhtid;
    }

    public String getHbh() {
        return hbh;
    }

    public void setHbh(String hbh) {
        this.hbh = hbh;
    }

    public String getFwzl() {
        return fwzl;
    }

    public void setFwzl(String fwzl) {
        this.fwzl = fwzl;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public String getJcnf() {
        return jcnf;
    }

    public void setJcnf(String jcnf) {
        this.jcnf = jcnf;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public String getXzql() {
        return xzql;
    }

    public void setXzql(String xzql) {
        this.xzql = xzql;
    }

    public Date getXzqljcqx() {
        return xzqljcqx;
    }

    public void setXzqljcqx(Date xzqljcqx) {
        this.xzqljcqx = xzqljcqx;
    }

    public Date getJfsj() {
        return jfsj;
    }

    public void setJfsj(Date jfsj) {
        this.jfsj = jfsj;
    }

    public String getJfzk() {
        return jfzk;
    }

    public void setJfzk(String jfzk) {
        this.jfzk = jfzk;
    }

    public String getQtsm() {
        return qtsm;
    }

    public void setQtsm(String qtsm) {
        this.qtsm = qtsm;
    }
}

==> estateplat-common-1.2.3-20180223.044413-30-sources.jar: cn/gtmap/estateplat/model/stockHouse/contract/LsFcjyClfJjhtFwgk.java <==
package cn.gtmap.estateplat.model.stockHouse.contract;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
 * @version 1.0, 2018/1/16
 * @description 经纪合同房屋概况
 */
@Table(name = "ls_fcjy_clf_jjht_fwgk")
public class LsFcjyClfJjhtFwgk implements InsertVo{
    @Id
    private String id;//id
    private String jjhtid;//经纪合同id
    private String hbh;//户编号
    private String fwzl;//房屋坐落
    private String cqzh;//产权证号
    private String fwxz;//房屋性质
    private String jcnf;//建成年份
    private Double jzmj;//建筑面积
    private String xzql;//限制权利
    private Date xzqljcqx;//限制权利解除期限
    private Date jfsj;//交付时间
    private String jfzk;//交付状况
    private String qtsm;//其他说明
    private String fwlx;//房屋性质
    private String fwjg;//房屋结构
    private String ghyt;//规划用途
    private String yfwxz;//原房屋性质
    private String yfwlx;//原房屋类型
    private String yfwjg;//原房屋结构
    private String yghyt;//原规划用途


    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getJjhtid() {
        return jjhtid;
    }

    public void setJjhtid(String jjhtid) {
        this.jjhtid = jjhtid;
    }

    public String getHbh() {
        return hbh;
    }

    public void setHbh(String hbh) {
        this.hbh = hbh;
    }

    public String getFwzl() {
        return fwzl;
    }

    public void setFwzl(String fwzl) {
        this.fwzl = fwzl;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public String getJcnf() {
        return jcnf;
    }

    public void setJcnf(String jcnf) {
        this.jcnf = jcnf;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public String getXzql() {
        return xzql;
    }

    public void setXzql(String xzql) {
        this.xzql = xzql;
    }

    public Date getXzqljcqx() {
        return xzqljcqx;
    }

    public void setXzqljcqx(Date xzqljcqx) {
        this.xzqljcqx = xzqljcqx;
    }

    public Date getJfsj() {
        return jfsj;
    }

    public void setJfsj(Date jfsj) {
        this.jfsj = jfsj;
    }

    public String getJfzk() {
        return jfzk;
    }

    public void setJfzk(String jfzk) {
        this.jfzk = jfzk;
    }

    public String getQtsm() {
        return qtsm;
    }

    public void setQtsm(String qtsm) {
        this.qtsm = qtsm;
    }

    public String getFwlx() {
        return fwlx;
    }

    public void setFwlx(String fwlx) {
        this.fwlx = fwlx;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getYfwxz() {
        return yfwxz;
    }

    public void setYfwxz(String yfwxz) {
        this.yfwxz = yfwxz;
    }

    public String getYfwlx() {
        return yfwlx;
    }

    public void setYfwlx(String yfwlx) {
        this.yfwlx = yfwlx;
    }

    public String getYfwjg() {
        return yfwjg;
    }

    public void setYfwjg(String yfwjg) {
        this.yfwjg = yfwjg;
    }

    public String getYghyt() {
        return yghyt;
    }

    public void setYghyt(String yghyt) {
        this.yghyt = yghyt;
    }
}
